package industries.doublehelix.pwste;


import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.stream.Stream;

import net.jpountz.lz4.LZ4Factory;
import net.jpountz.lz4.LZ4FastDecompressor;

public class LZ4Tester {
	public static void main(String[] args) throws IOException {
		Path saveDir = Paths.get("C:\\Users\\Akhlys\\AppData\\LocalLow\\FuturLab\\PowerWash Simulator\\SaveData\\0\\CAREER_AIRPORT_PRIVATEJET_TIMELAPSE");
		//Path saveFile = saveDir.resolve("CAREER_AIRPORT_PRIVATEJET_TIMELAPSE_100.sav");
		Path saveImgDir = saveDir.resolve("savedImages");
		
		Files.createDirectory(saveImgDir);
		
		try (Stream<Path> filePathStream = Files.list(saveDir)) {
			filePathStream.forEach(filePath -> {
				if (filePath.getFileName().toString().toLowerCase().endsWith(".sav")) {
					Path target = saveImgDir.resolve(filePath.getFileName() + ".jpg");
					try {
						handleFile(filePath, target);
					} catch (IOException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
				}
			});
		}
	}
	
	private static void handleFile(Path saveFile, Path result) throws IOException {
		byte[] file = Files.readAllBytes(saveFile);
		ByteBuffer uncompressedSizeWrap = ByteBuffer.wrap(Arrays.copyOfRange(file, 8, 12));
		uncompressedSizeWrap.order(ByteOrder.LITTLE_ENDIAN);
		int uncompressedSize = uncompressedSizeWrap.getInt();
		//System.out.println("UnCompressed size 1: " + uncompressedSize);

		ByteBuffer uncompressedSize2Wrap = ByteBuffer.wrap(Arrays.copyOfRange(file, 16, 20));
		uncompressedSize2Wrap.order(ByteOrder.LITTLE_ENDIAN);
		int uncompressedSize2 = uncompressedSize2Wrap.getInt();
		//System.out.println("UnCompressed size 2: " + uncompressedSize2);
		
		ByteBuffer compressedSizeWrap = ByteBuffer.wrap(Arrays.copyOfRange(file, 12, 16));
		compressedSizeWrap.order(ByteOrder.LITTLE_ENDIAN);
		int compressedSize = compressedSizeWrap.getInt();
		//System.out.println("Compressed size: " + uncompressedSize);
		
		
		// skip 20 bytes
		byte[] realFile = Arrays.copyOfRange(file, 20, file.length);
		//System.out.println(new String(realFile, StandardCharsets.UTF_8).substring(0, 50));
		
		LZ4Factory factory = LZ4Factory.fastestInstance();
		LZ4FastDecompressor decompressor = factory.fastDecompressor();
		byte[] restored = new byte[uncompressedSize2];
		int compressedLength2 = decompressor.decompress(realFile, 0, restored, 0, uncompressedSize2);

		//System.out.println(new String(restored, StandardCharsets.UTF_8).substring(0, 50));
		
		// save
		try {
			Files.write(result, restored);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
